use serde::{Deserialize, Serialize};

// 可编辑的配置，一般位于 /etc/cuavrs 下
#[derive(Clone, Debug, Deserialize, Serialize)]
pub struct Config {
    // 从此处更新 updateinfo, 以及 cusa 数据库
    remote: String,

    // 本地数据存储位置
    // /var/cache/cuvars
    local: String,
}

impl Config {
    // 从文件中读取配置信息
    pub fn from(path: &str) -> crate::Result<Self> {
        let data = std::fs::read_to_string(path)?;

        Ok(serde_json::from_str::<Self>(&data)?)
    }

    // 从此地址获取更新
    pub fn remote(&self) -> &str {
        &self.remote
    }

    // 本地数据存储位置
    pub fn local(&self) -> &str {
        &self.local
    }

    pub fn update(&self) -> crate::Result<()> {
        // TODO
        Ok(())
    }

    pub fn updateinfo(&self) -> String {
        format!("{}/updateinfo.xml", &self.local)
    }

    pub fn sainfo(&self) -> String {
        format!("{}/sainfos.json", &self.local)
    }
}
